{$ ::ctrl.listener.description $}

Protocol
  {$ ::ctrl.listener.protocol $}
Protocol Port
  {$ ::ctrl.listener.protocol_port $}
Connection Limit
  {$ ctrl.listener.connection_limit | limit $}
Admin State Up
  {$ ctrl.listener.admin_state_up | yesno $}
Default Pool ID
  {$ ::ctrl.listener.default_pool_id $} {$ 'None' | translate $}
Listener ID
  {$ ::ctrl.listener.id $}
Project ID
  {$ ::ctrl.listener.project_id $}
Created At
  {$ ::ctrl.listener.created_at $}
Updated At
  {$ ::ctrl.listener.updated_at $}